@@ -4,7 +4,7 @@ use anyhow::anyhow;
 use http::{header::HeaderName, HeaderMap, HeaderValue};
 use http_signature_normalization_actix::Config as ConfigActix;
 use http_signature_normalization_reqwest::prelude::{Config, SignExt};
-use lemmy_utils::LemmyError;
+use lemmy_utils::{LemmyError, REQWEST_TIMEOUT};
 use once_cell::sync::Lazy;
 use openssl::{
   hash::MessageDigest,
@@ -46,6 +46,8 @@ pub async fn sign_and_send(
 
   let request = client
     .post(&inbox_url.to_string())
+    // signature is only valid for 10 seconds, so no reason to wait any longer
+    .timeout(REQWEST_TIMEOUT)
     .headers(headers)
     .signature_with_digest(
       HTTP_SIG_CONFIG.clone(),
